@@ -22,12 +22,8 @@ from torchmetrics import Accuracy
 
 from pytorch_accelerated.callbacks import (
     TrainerCallback,
-    TerminateOnNaNCallback,
-    PrintMetricsCallback,
-    PrintProgressCallback,
-    ProgressBarCallback,
 )
-from pytorch_accelerated.trainer import Trainer
+from pytorch_accelerated.trainer import Trainer, DEFAULT_CALLBACKS
 
 
 class TimmTrainer(Trainer):
@@ -37,7 +33,7 @@ class TimmTrainer(Trainer):
         self.train_loss_func = kwargs["loss_func"]
         self.eval_loss_func = eval_loss_func
 
-    def create_train_dataloader(self, batch_size, train_dl_kwargs):
+    def create_train_dataloader(self, batch_size: int, train_dl_kwargs: dict = None):
 
         return timm.data.create_loader(
             dataset=self.train_dataset,
@@ -46,7 +42,7 @@ class TimmTrainer(Trainer):
             **train_dl_kwargs
         )
 
-    def create_eval_dataloader(self, batch_size, eval_dl_kwargs):
+    def create_eval_dataloader(self, batch_size: int, eval_dl_kwargs: dict = None):
 
         return timm.data.create_loader(
             dataset=self.eval_dataset,
@@ -79,7 +75,7 @@ class AccuracyCallback(TrainerCallback):
         self.accuracy = Accuracy(num_classes=num_classes)
 
     def on_training_run_start(self, trainer, **kwargs):
-        self.accuracy.to(trainer._eval_dataloader.device)
+        self.accuracy.to(trainer.device)
 
     def on_eval_step_end(self, trainer, batch, batch_output, **kwargs):
         preds = batch_output["model_outputs"].argmax(dim=-1)
@@ -177,13 +173,7 @@ def main():
         optimizer=optimizer,
         loss_func=train_loss_fn,
         eval_loss_func=validate_loss_fn,
-        callbacks=(
-            TerminateOnNaNCallback,
-            AccuracyCallback(num_classes=num_classes),
-            PrintMetricsCallback,
-            PrintProgressCallback,
-            ProgressBarCallback,
-        ),
+        callbacks=(AccuracyCallback(num_classes=num_classes), *DEFAULT_CALLBACKS),
     )
 
     trainer.train(
